#!/usr/bin/env python

"""Tests for `openthaigpt` package."""


import unittest

from openthaigpt import openthaigpt_module

class TestOpenthaigpt(unittest.TestCase):
    """Tests for `openthaigpt` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_0000_usage(self):
        """Test something."""
        answer = openthaigpt_module.generate("Q: สวัสดีครับ")
        assert answer is not None



"""Main module."""
from transformers import GPT2Tokenizer, GPT2LMHeadModel
from evaluate import load
pretrained_name = "kobkrit/openthaigpt-gpt2-instructgpt-poc-0.0.4"

tokenizer = GPT2Tokenizer.from_pretrained(pretrained_name, bos_token='<|startoftext|>',unk_token='<|unk|>', eos_token='<|endoftext|>', pad_token='<|pad|>')
model = GPT2LMHeadModel.from_pretrained(pretrained_name).cuda()
model.resize_token_embeddings(len(tokenizer))

def generate(input, max_length=300, top_k=50, top_p=0.95, num_beam=5, no_repeat_ngram_size=2, early_stopping=True, temperature=1.9):
    generated = tokenizer("<|startoftext|>"+input, return_tensors="pt").input_ids.cuda()
    output = model.generate(generated, top_k=top_k, num_beams=num_beam, no_repeat_ngram_size=no_repeat_ngram_size, 
        early_stopping=early_stopping, max_length=max_length, top_p=top_p, temperature=temperature)
    return tokenizer.decode(output[0], skip_special_tokens=True)

def zero(input, threshold=10):
    perplexity = load("perplexity", module_type="metric")
    results = perplexity.compute(predictions=[input], model_id=pretrained_name)
    score = results['perplexities'][0]
    isGeneratedFromOpenThaiGPT = False
    if (score < threshold):
        isGeneratedFromOpenThaiGPT = True
    return {'perplexity':score, 'theshold':threshold, 'isGeneratedFromOpenThaiGPT':isGeneratedFromOpenThaiGPT}


#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.md') as history_file:
    history = history_file.read()

requirements = [
    'transformers[sentencepiece]',
    'torch',
    'evaluate'
]

test_requirements = [ ]

setup(
    author="Kobkrit Viriyayudhakorn",
    author_email='kobkrit@iapp.co.th',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Natural Language :: Thai',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ],
    description="OpenThaiGPT focuses on developing a Thai Chatbot system to have capabilities equivalent to ChatGPT, as well as being able to connect to external systems and be able to retrieve data flexibly. Easily expandable and customizable and developed into Free open source software for everyone.",
    install_requires=requirements,
    license="Apache Software License 2.0",
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords='openthaigpt',
    name='openthaigpt',
    packages=find_packages(include=['openthaigpt', 'openthaigpt.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/OpenThaiGPT/openthaigpt',
    version='0.0.9',
    zip_safe=False,
)
